@@ -66,13 +66,20 @@ function ct_registration()
     DISPLAY_NAME=$(get_product_parameter cms_cluster_name)
 
     #cert_info
-    SERVER_KEYSTORE_B64=$(get_product_parameter cms_ssl.serverkeystoreb64)
-    CLIENT_AUTH=$(get_product_parameter cms_ssl.client_auth_keystorejksb64)
-    TRUST_STORE_JKS=$(get_product_parameter cms_ssl.cms_truststorejksb64)
-    KEYSTORE_PASS=$(get_product_parameter cms_ssl.keystorepassb64)
-    CMS_FINGERPRINT=$(get_product_parameter cms_ssl.cms_fingerprintb64)
-    APP_PEM=$(get_product_parameter cms_ssl.apppemb64)
-    CLIENT_PEM=$(get_product_parameter cms_ssl.clientpemb64)
+    #SERVER_KEYSTORE_B64=$(get_product_parameter cms_ssl.serverkeystoreb64)
+    #CLIENT_AUTH=$(get_product_parameter cms_ssl.client_auth_keystorejksb64)
+    #TRUST_STORE_JKS=$(get_product_parameter cms_ssl.cms_truststorejksb64)
+    #KEYSTORE_PASS=$(get_product_parameter cms_ssl.keystorepassb64)
+    #CMS_FINGERPRINT=$(get_product_parameter cms_ssl.cms_fingerprintb64)
+    #APP_PEM=$(get_product_parameter cms_ssl.apppemb64)
+    #CLIENT_PEM=$(get_product_parameter cms_ssl.clientpemb64)
+    SERVER_KEYSTORE_B64=$(get_secret_data_b64 cms-app-server-cert server.keystore)
+    CLIENT_AUTH=$(get_secret_data_b64 cms-trusted-ssl-cert client_auth_keystore.jks)
+    TRUST_STORE_JKS=$(get_secret_data_b64 cms-trusted-ssl-cert cms_truststore.jks)
+    KEYSTORE_PASS=$(get_secret_data_b64 cms-trusted-ssl-cert keystore.pass)
+    CMS_FINGERPRINT=$(get_secret_data_b64 cms-trusted-ssl-cert cms_fingerprint)
+    APP_PEM=$(get_secret_data_b64 cms-haproxy app.pem)
+    CLIENT_PEM=$(get_secret_data_b64 cms-haproxy clients.pem)
 
     #redis_info
     REDIS_PORT=6379
@@ -109,20 +116,21 @@ function ct_registration()
     }" > /tmp/cms_ct_info.json
 
     ####CT information######
-    echo "===================External CT information=================="
-    cat /tmp/cms_ct_info.json
+    #echo "===================External CT information=================="
+    #cat /tmp/cms_ct_info.json
 
     #Generate client.pem file for CT registeration.
-    PEER_CLIENT_PEM=$(get_product_parameter cms_peer_ssl.clientpemb64)
+    #PEER_CLIENT_PEM=$(get_product_parameter cms_peer_ssl.clientpemb64)
+    PEER_CLIENT_PEM=$(get_secret_data_b64 peer-cms-trusted-ssl-cert clients.pem)
     #echo "$PEER_CLIENT_PEM" | base64 --decode > /tmp/client.pem
     echo "$PEER_CLIENT_PEM" | base64 -d > /tmp/client.pem
     
     #Send the CT registration request
     REGSITER=$(curl -s -m 10 -k -H 'Content-type':'application/json' --cert /tmp/client.pem -X PUT -d @/tmp/cms_ct_info.json https://$CORE_VIP:8443/ctmanager/registration)
-    echo $REGSITER
     if [[ $REGSITER =~ 200 ]];then
         echo "[INFO]Register external CT to Core [$CORE_VIP] successfully."
     else
+        echo "[ERROR] Register external CT failed with message: $REGSITER"
         exit 1
     fi
     
